# Generated by Django 5.2.6 on 2025-09-30 00:36

import _socket
import django.core.validators
import django.db.models.deletion
import django.utils.timezone
import django_audit_fields.fields.hostname_modification_field
import django_audit_fields.fields.userfield
import django_audit_fields.fields.uuid_auto_field
import django_revision.revision_field
import edc_crf.model_mixins.crf_status_model_mixin
import edc_model.models.fields.initials_field
import edc_model.validators.date
import edc_model_fields.fields.other_charfield
import edc_protocol.validators
import edc_visit_tracking.managers
import simple_history.models
import uuid
from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("meta_subject", "0228_bloodresultshba1c_hba1c_datetime_and_more"),
        ("sites", "0002_alter_domain_unique"),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.AlterField(
            model_name="glucosefbg",
            name="consent_model",
            field=models.CharField(blank=True, default="", max_length=50),
        ),
        migrations.AlterField(
            model_name="glucosefbg",
            name="consent_version",
            field=models.CharField(blank=True, default="", max_length=10),
        ),
        migrations.AlterField(
            model_name="glucosefbg",
            name="crf_status_comments",
            field=models.TextField(
                blank=True,
                default="",
                help_text="for example, why some data is still pending",
                verbose_name="Any comments related to status of this CRF",
            ),
        ),
        migrations.AlterField(
            model_name="glucosefbg",
            name="device_created",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device created"
            ),
        ),
        migrations.AlterField(
            model_name="glucosefbg",
            name="device_modified",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="glucosefbg",
            name="fbg_not_performed_reason",
            field=models.CharField(
                blank=True,
                default="",
                max_length=150,
                verbose_name="If NO, provide reason",
            ),
        ),
        migrations.AlterField(
            model_name="glucosefbg",
            name="locale_created",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale created",
            ),
        ),
        migrations.AlterField(
            model_name="glucosefbg",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="glucosefbg",
            name="report_datetime",
            field=models.DateTimeField(
                default=django.utils.timezone.now,
                help_text="If reporting today, use today's date/time, otherwise use the date/time this information was reported.",
                validators=[
                    edc_protocol.validators.datetime_not_before_study_start,
                    edc_model.validators.date.datetime_not_future,
                ],
                verbose_name="Report Date",
            ),
        ),
        migrations.AlterField(
            model_name="glucosefbg",
            name="revision",
            field=django_revision.revision_field.RevisionField(
                blank=True,
                default="",
                editable=False,
                help_text="System field. From git repository (tag:branch:commit), project metadata, project toml, project VERSION, or settings.",
                max_length=75,
                verbose_name="Revision",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomics",
            name="consent_model",
            field=models.CharField(blank=True, default="", max_length=50),
        ),
        migrations.AlterField(
            model_name="healtheconomics",
            name="consent_version",
            field=models.CharField(blank=True, default="", max_length=10),
        ),
        migrations.AlterField(
            model_name="healtheconomics",
            name="crf_status_comments",
            field=models.TextField(
                blank=True,
                default="",
                help_text="for example, why some data is still pending",
                verbose_name="Any comments related to status of this CRF",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomics",
            name="device_created",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device created"
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomics",
            name="device_modified",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomics",
            name="expenditure_other_detail",
            field=models.TextField(
                blank=True, default="", verbose_name="If YES, what was the activity"
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomics",
            name="highest_earner",
            field=models.CharField(
                blank=True,
                default="",
                max_length=50,
                verbose_name="If NO, what is the profession of the person who earns the highest income?",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomics",
            name="locale_created",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale created",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomics",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomics",
            name="report_datetime",
            field=models.DateTimeField(
                default=django.utils.timezone.now,
                help_text="If reporting today, use today's date/time, otherwise use the date/time this information was reported.",
                validators=[
                    edc_protocol.validators.datetime_not_before_study_start,
                    edc_model.validators.date.datetime_not_future,
                ],
                verbose_name="Report Date",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomics",
            name="revision",
            field=django_revision.revision_field.RevisionField(
                blank=True,
                default="",
                editable=False,
                help_text="System field. From git repository (tag:branch:commit), project metadata, project toml, project VERSION, or settings.",
                max_length=75,
                verbose_name="Revision",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomics",
            name="routine_activities_other",
            field=models.CharField(
                blank=True,
                default="",
                max_length=50,
                verbose_name="If OTHER, please specify",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicssimple",
            name="consent_model",
            field=models.CharField(blank=True, default="", max_length=50),
        ),
        migrations.AlterField(
            model_name="healtheconomicssimple",
            name="consent_version",
            field=models.CharField(blank=True, default="", max_length=10),
        ),
        migrations.AlterField(
            model_name="healtheconomicssimple",
            name="crf_status_comments",
            field=models.TextField(
                blank=True,
                default="",
                help_text="for example, why some data is still pending",
                verbose_name="Any comments related to status of this CRF",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicssimple",
            name="device_created",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device created"
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicssimple",
            name="device_modified",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicssimple",
            name="education_certificate",
            field=models.CharField(
                choices=[
                    ("primary", "Primary Certificate"),
                    ("secondary", "Secondary Certificate"),
                    ("tertiary", "post-Secondary/Tertiary/College"),
                    ("OTHER", "Other, specify ..."),
                    ("N/A", "Not applicable, never went to school"),
                ],
                default="",
                max_length=50,
                verbose_name="What is your highest education certificate?",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicssimple",
            name="education_certificate_tertiary",
            field=models.CharField(
                blank=True,
                default="",
                max_length=50,
                verbose_name="If your highest education certificate above is `Tertiary`, what type of tertiary certificate?",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicssimple",
            name="locale_created",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale created",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicssimple",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicssimple",
            name="report_datetime",
            field=models.DateTimeField(
                default=django.utils.timezone.now,
                help_text="If reporting today, use today's date/time, otherwise use the date/time this information was reported.",
                validators=[
                    edc_protocol.validators.datetime_not_before_study_start,
                    edc_model.validators.date.datetime_not_future,
                ],
                verbose_name="Report Date",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicssimple",
            name="revision",
            field=django_revision.revision_field.RevisionField(
                blank=True,
                default="",
                editable=False,
                help_text="System field. From git repository (tag:branch:commit), project metadata, project toml, project VERSION, or settings.",
                max_length=75,
                verbose_name="Revision",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsupdate",
            name="consent_model",
            field=models.CharField(blank=True, default="", max_length=50),
        ),
        migrations.AlterField(
            model_name="healtheconomicsupdate",
            name="consent_version",
            field=models.CharField(blank=True, default="", max_length=10),
        ),
        migrations.AlterField(
            model_name="healtheconomicsupdate",
            name="crf_status_comments",
            field=models.TextField(
                blank=True,
                default="",
                help_text="for example, why some data is still pending",
                verbose_name="Any comments related to status of this CRF",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsupdate",
            name="device_created",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device created"
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsupdate",
            name="device_modified",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsupdate",
            name="locale_created",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale created",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsupdate",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsupdate",
            name="relationship_to_hoh_other",
            field=edc_model_fields.fields.other_charfield.OtherCharField(
                blank=True,
                default="",
                max_length=35,
                verbose_name="If OTHER relationship, specify ...",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsupdate",
            name="report_datetime",
            field=models.DateTimeField(
                default=django.utils.timezone.now,
                help_text="If reporting today, use today's date/time, otherwise use the date/time this information was reported.",
                validators=[
                    edc_protocol.validators.datetime_not_before_study_start,
                    edc_model.validators.date.datetime_not_future,
                ],
                verbose_name="Report Date",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsupdate",
            name="revision",
            field=django_revision.revision_field.RevisionField(
                blank=True,
                default="",
                editable=False,
                help_text="System field. From git repository (tag:branch:commit), project metadata, project toml, project VERSION, or settings.",
                max_length=75,
                verbose_name="Revision",
            ),
        ),
        migrations.AlterField(
            model_name="hepatitistest",
            name="consent_model",
            field=models.CharField(blank=True, default="", max_length=50),
        ),
        migrations.AlterField(
            model_name="hepatitistest",
            name="consent_version",
            field=models.CharField(blank=True, default="", max_length=10),
        ),
        migrations.AlterField(
            model_name="hepatitistest",
            name="crf_status_comments",
            field=models.TextField(
                blank=True,
                default="",
                help_text="for example, why some data is still pending",
                verbose_name="Any comments related to status of this CRF",
            ),
        ),
        migrations.AlterField(
            model_name="hepatitistest",
            name="device_created",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device created"
            ),
        ),
        migrations.AlterField(
            model_name="hepatitistest",
            name="device_modified",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="hepatitistest",
            name="hbsag",
            field=models.CharField(
                blank=True,
                choices=[
                    ("POS", "Positive"),
                    ("NEG", "Negative"),
                    ("IND", "Indeterminate"),
                ],
                default="",
                max_length=15,
                verbose_name="<u>HbSAg</u>",
            ),
        ),
        migrations.AlterField(
            model_name="hepatitistest",
            name="hcv",
            field=models.CharField(
                blank=True,
                choices=[
                    ("POS", "Positive"),
                    ("NEG", "Negative"),
                    ("IND", "Indeterminate"),
                ],
                default="",
                max_length=15,
                verbose_name="<u>HCV</u>",
            ),
        ),
        migrations.AlterField(
            model_name="hepatitistest",
            name="locale_created",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale created",
            ),
        ),
        migrations.AlterField(
            model_name="hepatitistest",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="hepatitistest",
            name="report_datetime",
            field=models.DateTimeField(
                default=django.utils.timezone.now,
                help_text="If reporting today, use today's date/time, otherwise use the date/time this information was reported.",
                validators=[
                    edc_protocol.validators.datetime_not_before_study_start,
                    edc_model.validators.date.datetime_not_future,
                ],
                verbose_name="Report Date",
            ),
        ),
        migrations.AlterField(
            model_name="hepatitistest",
            name="revision",
            field=django_revision.revision_field.RevisionField(
                blank=True,
                default="",
                editable=False,
                help_text="System field. From git repository (tag:branch:commit), project metadata, project toml, project VERSION, or settings.",
                max_length=75,
                verbose_name="Revision",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbirthoutcomes",
            name="consent_model",
            field=models.CharField(blank=True, default="", max_length=50),
        ),
        migrations.AlterField(
            model_name="historicalbirthoutcomes",
            name="consent_version",
            field=models.CharField(blank=True, default="", max_length=10),
        ),
        migrations.AlterField(
            model_name="historicalbirthoutcomes",
            name="crf_status_comments",
            field=models.TextField(
                blank=True,
                default="",
                help_text="for example, why some data is still pending",
                verbose_name="Any comments related to status of this CRF",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbirthoutcomes",
            name="device_created",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device created"
            ),
        ),
        migrations.AlterField(
            model_name="historicalbirthoutcomes",
            name="device_modified",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="historicalbirthoutcomes",
            name="locale_created",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale created",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbirthoutcomes",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbirthoutcomes",
            name="revision",
            field=django_revision.revision_field.RevisionField(
                blank=True,
                default="",
                editable=False,
                help_text="System field. From git repository (tag:branch:commit), project metadata, project toml, project VERSION, or settings.",
                max_length=75,
                verbose_name="Revision",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsfbc",
            name="abnormal_summary",
            field=models.TextField(blank=True, default=""),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsfbc",
            name="action_identifier",
            field=models.CharField(blank=True, db_index=True, default="", max_length=50),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsfbc",
            name="action_item_reason",
            field=models.TextField(default="", editable=False),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsfbc",
            name="consent_model",
            field=models.CharField(blank=True, default="", max_length=50),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsfbc",
            name="consent_version",
            field=models.CharField(blank=True, default="", max_length=10),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsfbc",
            name="crf_status_comments",
            field=models.TextField(
                blank=True,
                default="",
                help_text="for example, why some data is still pending",
                verbose_name="Any comments related to status of this CRF",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsfbc",
            name="device_created",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device created"
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsfbc",
            name="device_modified",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsfbc",
            name="errors",
            field=models.TextField(blank=True, default=""),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsfbc",
            name="locale_created",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale created",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsfbc",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsfbc",
            name="missing",
            field=models.TextField(
                default="",
                editable=False,
                help_text="calculated string of field names that have been left blank",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsfbc",
            name="parent_action_identifier",
            field=models.CharField(
                blank=True,
                default="",
                help_text="action identifier that links to parent reference model instance.",
                max_length=30,
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsfbc",
            name="related_action_identifier",
            field=models.CharField(
                blank=True,
                default="",
                help_text="action identifier that links to related reference model instance.",
                max_length=30,
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsfbc",
            name="report_datetime",
            field=models.DateTimeField(
                default=django.utils.timezone.now,
                help_text="If reporting today, use today's date/time, otherwise use the date/time this information was reported.",
                validators=[
                    edc_protocol.validators.datetime_not_before_study_start,
                    edc_model.validators.date.datetime_not_future,
                ],
                verbose_name="Report Date",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsfbc",
            name="reportable_summary",
            field=models.TextField(blank=True, default=""),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsfbc",
            name="revision",
            field=django_revision.revision_field.RevisionField(
                blank=True,
                default="",
                editable=False,
                help_text="System field. From git repository (tag:branch:commit), project metadata, project toml, project VERSION, or settings.",
                max_length=75,
                verbose_name="Revision",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsfbc",
            name="summary",
            field=models.TextField(blank=True, default=""),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsgludummy",
            name="abnormal_summary",
            field=models.TextField(blank=True, default=""),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsgludummy",
            name="action_identifier",
            field=models.CharField(blank=True, db_index=True, default="", max_length=50),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsgludummy",
            name="action_item_reason",
            field=models.TextField(default="", editable=False),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsgludummy",
            name="consent_model",
            field=models.CharField(blank=True, default="", max_length=50),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsgludummy",
            name="consent_version",
            field=models.CharField(blank=True, default="", max_length=10),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsgludummy",
            name="crf_status_comments",
            field=models.TextField(
                blank=True,
                default="",
                help_text="for example, why some data is still pending",
                verbose_name="Any comments related to status of this CRF",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsgludummy",
            name="device_created",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device created"
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsgludummy",
            name="device_modified",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsgludummy",
            name="errors",
            field=models.TextField(blank=True, default=""),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsgludummy",
            name="fasting",
            field=models.CharField(
                choices=[("fasting", "Fasting"), ("non_fasting", "Non-fasting")],
                default="",
                max_length=25,
                verbose_name="Was this fasting or non-fasting?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsgludummy",
            name="is_poc",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="",
                max_length=15,
                verbose_name="Was a point-of-care test used?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsgludummy",
            name="locale_created",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale created",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsgludummy",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsgludummy",
            name="missing",
            field=models.TextField(
                default="",
                editable=False,
                help_text="calculated string of field names that have been left blank",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsgludummy",
            name="parent_action_identifier",
            field=models.CharField(
                blank=True,
                default="",
                help_text="action identifier that links to parent reference model instance.",
                max_length=30,
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsgludummy",
            name="related_action_identifier",
            field=models.CharField(
                blank=True,
                default="",
                help_text="action identifier that links to related reference model instance.",
                max_length=30,
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsgludummy",
            name="report_datetime",
            field=models.DateTimeField(
                default=django.utils.timezone.now,
                help_text="If reporting today, use today's date/time, otherwise use the date/time this information was reported.",
                validators=[
                    edc_protocol.validators.datetime_not_before_study_start,
                    edc_model.validators.date.datetime_not_future,
                ],
                verbose_name="Report Date",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsgludummy",
            name="reportable_summary",
            field=models.TextField(blank=True, default=""),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsgludummy",
            name="revision",
            field=django_revision.revision_field.RevisionField(
                blank=True,
                default="",
                editable=False,
                help_text="System field. From git repository (tag:branch:commit), project metadata, project toml, project VERSION, or settings.",
                max_length=75,
                verbose_name="Revision",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsgludummy",
            name="summary",
            field=models.TextField(blank=True, default=""),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultshba1c",
            name="abnormal_summary",
            field=models.TextField(blank=True, default=""),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultshba1c",
            name="action_identifier",
            field=models.CharField(blank=True, db_index=True, default="", max_length=50),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultshba1c",
            name="action_item_reason",
            field=models.TextField(default="", editable=False),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultshba1c",
            name="consent_model",
            field=models.CharField(blank=True, default="", max_length=50),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultshba1c",
            name="consent_version",
            field=models.CharField(blank=True, default="", max_length=10),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultshba1c",
            name="crf_status_comments",
            field=models.TextField(
                blank=True,
                default="",
                help_text="for example, why some data is still pending",
                verbose_name="Any comments related to status of this CRF",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultshba1c",
            name="device_created",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device created"
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultshba1c",
            name="device_modified",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultshba1c",
            name="errors",
            field=models.TextField(blank=True, default=""),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultshba1c",
            name="hba1c_abnormal",
            field=models.CharField(
                blank=True,
                choices=[("Yes", "Yes"), ("No", "No")],
                default="",
                max_length=25,
                verbose_name="abnormal",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultshba1c",
            name="hba1c_quantifier",
            field=models.CharField(
                default="=",
                editable=False,
                max_length=10,
                verbose_name="HbA1c quantifier",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultshba1c",
            name="hba1c_reportable",
            field=models.CharField(
                blank=True,
                choices=[
                    ("N/A", "Not applicable"),
                    ("3", "Yes, grade 3"),
                    ("4", "Yes, grade 4"),
                    ("No", "Not reportable"),
                    ("Already reported", "Already reported"),
                    ("present_at_baseline", "Present at baseline"),
                ],
                default="",
                max_length=25,
                verbose_name="reportable",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultshba1c",
            name="hba1c_units",
            field=models.CharField(
                blank=True, default="%", max_length=15, verbose_name="HbA1c units"
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultshba1c",
            name="hba1c_value",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                help_text="In percent. A `HIGH` reading may be entered as 9999.99",
                max_digits=8,
                null=True,
                verbose_name="HbA1c value",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultshba1c",
            name="is_poc",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="",
                max_length=15,
                verbose_name="Was a point-of-care test used?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultshba1c",
            name="locale_created",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale created",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultshba1c",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultshba1c",
            name="missing",
            field=models.TextField(
                default="",
                editable=False,
                help_text="calculated string of field names that have been left blank",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultshba1c",
            name="parent_action_identifier",
            field=models.CharField(
                blank=True,
                default="",
                help_text="action identifier that links to parent reference model instance.",
                max_length=30,
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultshba1c",
            name="related_action_identifier",
            field=models.CharField(
                blank=True,
                default="",
                help_text="action identifier that links to related reference model instance.",
                max_length=30,
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultshba1c",
            name="report_datetime",
            field=models.DateTimeField(
                default=django.utils.timezone.now,
                help_text="If reporting today, use today's date/time, otherwise use the date/time this information was reported.",
                validators=[
                    edc_protocol.validators.datetime_not_before_study_start,
                    edc_model.validators.date.datetime_not_future,
                ],
                verbose_name="Report Date",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultshba1c",
            name="reportable_summary",
            field=models.TextField(blank=True, default=""),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultshba1c",
            name="revision",
            field=django_revision.revision_field.RevisionField(
                blank=True,
                default="",
                editable=False,
                help_text="System field. From git repository (tag:branch:commit), project metadata, project toml, project VERSION, or settings.",
                max_length=75,
                verbose_name="Revision",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultshba1c",
            name="summary",
            field=models.TextField(blank=True, default=""),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsins",
            name="abnormal_summary",
            field=models.TextField(blank=True, default=""),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsins",
            name="action_identifier",
            field=models.CharField(blank=True, db_index=True, default="", max_length=50),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsins",
            name="action_item_reason",
            field=models.TextField(default="", editable=False),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsins",
            name="consent_model",
            field=models.CharField(blank=True, default="", max_length=50),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsins",
            name="consent_version",
            field=models.CharField(blank=True, default="", max_length=10),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsins",
            name="crf_status_comments",
            field=models.TextField(
                blank=True,
                default="",
                help_text="for example, why some data is still pending",
                verbose_name="Any comments related to status of this CRF",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsins",
            name="device_created",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device created"
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsins",
            name="device_modified",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsins",
            name="errors",
            field=models.TextField(blank=True, default=""),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsins",
            name="locale_created",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale created",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsins",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsins",
            name="missing",
            field=models.TextField(
                default="",
                editable=False,
                help_text="calculated string of field names that have been left blank",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsins",
            name="parent_action_identifier",
            field=models.CharField(
                blank=True,
                default="",
                help_text="action identifier that links to parent reference model instance.",
                max_length=30,
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsins",
            name="related_action_identifier",
            field=models.CharField(
                blank=True,
                default="",
                help_text="action identifier that links to related reference model instance.",
                max_length=30,
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsins",
            name="report_datetime",
            field=models.DateTimeField(
                default=django.utils.timezone.now,
                help_text="If reporting today, use today's date/time, otherwise use the date/time this information was reported.",
                validators=[
                    edc_protocol.validators.datetime_not_before_study_start,
                    edc_model.validators.date.datetime_not_future,
                ],
                verbose_name="Report Date",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsins",
            name="reportable_summary",
            field=models.TextField(blank=True, default=""),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsins",
            name="revision",
            field=django_revision.revision_field.RevisionField(
                blank=True,
                default="",
                editable=False,
                help_text="System field. From git repository (tag:branch:commit), project metadata, project toml, project VERSION, or settings.",
                max_length=75,
                verbose_name="Revision",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsins",
            name="summary",
            field=models.TextField(blank=True, default=""),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultslft",
            name="abnormal_summary",
            field=models.TextField(blank=True, default=""),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultslft",
            name="action_identifier",
            field=models.CharField(blank=True, db_index=True, default="", max_length=50),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultslft",
            name="action_item_reason",
            field=models.TextField(default="", editable=False),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultslft",
            name="consent_model",
            field=models.CharField(blank=True, default="", max_length=50),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultslft",
            name="consent_version",
            field=models.CharField(blank=True, default="", max_length=10),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultslft",
            name="crf_status_comments",
            field=models.TextField(
                blank=True,
                default="",
                help_text="for example, why some data is still pending",
                verbose_name="Any comments related to status of this CRF",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultslft",
            name="device_created",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device created"
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultslft",
            name="device_modified",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultslft",
            name="errors",
            field=models.TextField(blank=True, default=""),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultslft",
            name="locale_created",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale created",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultslft",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultslft",
            name="missing",
            field=models.TextField(
                default="",
                editable=False,
                help_text="calculated string of field names that have been left blank",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultslft",
            name="parent_action_identifier",
            field=models.CharField(
                blank=True,
                default="",
                help_text="action identifier that links to parent reference model instance.",
                max_length=30,
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultslft",
            name="related_action_identifier",
            field=models.CharField(
                blank=True,
                default="",
                help_text="action identifier that links to related reference model instance.",
                max_length=30,
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultslft",
            name="report_datetime",
            field=models.DateTimeField(
                default=django.utils.timezone.now,
                help_text="If reporting today, use today's date/time, otherwise use the date/time this information was reported.",
                validators=[
                    edc_protocol.validators.datetime_not_before_study_start,
                    edc_model.validators.date.datetime_not_future,
                ],
                verbose_name="Report Date",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultslft",
            name="reportable_summary",
            field=models.TextField(blank=True, default=""),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultslft",
            name="revision",
            field=django_revision.revision_field.RevisionField(
                blank=True,
                default="",
                editable=False,
                help_text="System field. From git repository (tag:branch:commit), project metadata, project toml, project VERSION, or settings.",
                max_length=75,
                verbose_name="Revision",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultslft",
            name="summary",
            field=models.TextField(blank=True, default=""),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultslipids",
            name="abnormal_summary",
            field=models.TextField(blank=True, default=""),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultslipids",
            name="action_identifier",
            field=models.CharField(blank=True, db_index=True, default="", max_length=50),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultslipids",
            name="action_item_reason",
            field=models.TextField(default="", editable=False),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultslipids",
            name="consent_model",
            field=models.CharField(blank=True, default="", max_length=50),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultslipids",
            name="consent_version",
            field=models.CharField(blank=True, default="", max_length=10),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultslipids",
            name="crf_status_comments",
            field=models.TextField(
                blank=True,
                default="",
                help_text="for example, why some data is still pending",
                verbose_name="Any comments related to status of this CRF",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultslipids",
            name="device_created",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device created"
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultslipids",
            name="device_modified",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultslipids",
            name="errors",
            field=models.TextField(blank=True, default=""),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultslipids",
            name="locale_created",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale created",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultslipids",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultslipids",
            name="missing",
            field=models.TextField(
                default="",
                editable=False,
                help_text="calculated string of field names that have been left blank",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultslipids",
            name="parent_action_identifier",
            field=models.CharField(
                blank=True,
                default="",
                help_text="action identifier that links to parent reference model instance.",
                max_length=30,
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultslipids",
            name="related_action_identifier",
            field=models.CharField(
                blank=True,
                default="",
                help_text="action identifier that links to related reference model instance.",
                max_length=30,
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultslipids",
            name="report_datetime",
            field=models.DateTimeField(
                default=django.utils.timezone.now,
                help_text="If reporting today, use today's date/time, otherwise use the date/time this information was reported.",
                validators=[
                    edc_protocol.validators.datetime_not_before_study_start,
                    edc_model.validators.date.datetime_not_future,
                ],
                verbose_name="Report Date",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultslipids",
            name="reportable_summary",
            field=models.TextField(blank=True, default=""),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultslipids",
            name="revision",
            field=django_revision.revision_field.RevisionField(
                blank=True,
                default="",
                editable=False,
                help_text="System field. From git repository (tag:branch:commit), project metadata, project toml, project VERSION, or settings.",
                max_length=75,
                verbose_name="Revision",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultslipids",
            name="summary",
            field=models.TextField(blank=True, default=""),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsrft",
            name="abnormal_summary",
            field=models.TextField(blank=True, default=""),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsrft",
            name="action_identifier",
            field=models.CharField(blank=True, db_index=True, default="", max_length=50),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsrft",
            name="action_item_reason",
            field=models.TextField(default="", editable=False),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsrft",
            name="consent_model",
            field=models.CharField(blank=True, default="", max_length=50),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsrft",
            name="consent_version",
            field=models.CharField(blank=True, default="", max_length=10),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsrft",
            name="crf_status_comments",
            field=models.TextField(
                blank=True,
                default="",
                help_text="for example, why some data is still pending",
                verbose_name="Any comments related to status of this CRF",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsrft",
            name="device_created",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device created"
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsrft",
            name="device_modified",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsrft",
            name="errors",
            field=models.TextField(blank=True, default=""),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsrft",
            name="locale_created",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale created",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsrft",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsrft",
            name="missing",
            field=models.TextField(
                default="",
                editable=False,
                help_text="calculated string of field names that have been left blank",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsrft",
            name="parent_action_identifier",
            field=models.CharField(
                blank=True,
                default="",
                help_text="action identifier that links to parent reference model instance.",
                max_length=30,
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsrft",
            name="related_action_identifier",
            field=models.CharField(
                blank=True,
                default="",
                help_text="action identifier that links to related reference model instance.",
                max_length=30,
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsrft",
            name="report_datetime",
            field=models.DateTimeField(
                default=django.utils.timezone.now,
                help_text="If reporting today, use today's date/time, otherwise use the date/time this information was reported.",
                validators=[
                    edc_protocol.validators.datetime_not_before_study_start,
                    edc_model.validators.date.datetime_not_future,
                ],
                verbose_name="Report Date",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsrft",
            name="reportable_summary",
            field=models.TextField(blank=True, default=""),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsrft",
            name="revision",
            field=django_revision.revision_field.RevisionField(
                blank=True,
                default="",
                editable=False,
                help_text="System field. From git repository (tag:branch:commit), project metadata, project toml, project VERSION, or settings.",
                max_length=75,
                verbose_name="Revision",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsrft",
            name="summary",
            field=models.TextField(blank=True, default=""),
        ),
        migrations.AlterField(
            model_name="historicalcomplications",
            name="consent_model",
            field=models.CharField(blank=True, default="", max_length=50),
        ),
        migrations.AlterField(
            model_name="historicalcomplications",
            name="consent_version",
            field=models.CharField(blank=True, default="", max_length=10),
        ),
        migrations.AlterField(
            model_name="historicalcomplications",
            name="crf_status_comments",
            field=models.TextField(
                blank=True,
                default="",
                help_text="for example, why some data is still pending",
                verbose_name="Any comments related to status of this CRF",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcomplications",
            name="device_created",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device created"
            ),
        ),
        migrations.AlterField(
            model_name="historicalcomplications",
            name="device_modified",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="historicalcomplications",
            name="locale_created",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale created",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcomplications",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcomplications",
            name="report_datetime",
            field=models.DateTimeField(
                default=django.utils.timezone.now,
                help_text="If reporting today, use today's date/time, otherwise use the date/time this information was reported.",
                validators=[
                    edc_protocol.validators.datetime_not_before_study_start,
                    edc_model.validators.date.datetime_not_future,
                ],
                verbose_name="Report Date",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcomplications",
            name="revision",
            field=django_revision.revision_field.RevisionField(
                blank=True,
                default="",
                editable=False,
                help_text="System field. From git repository (tag:branch:commit), project metadata, project toml, project VERSION, or settings.",
                max_length=75,
                verbose_name="Revision",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcomplicationsglycemia",
            name="consent_model",
            field=models.CharField(blank=True, default="", max_length=50),
        ),
        migrations.AlterField(
            model_name="historicalcomplicationsglycemia",
            name="consent_version",
            field=models.CharField(blank=True, default="", max_length=10),
        ),
        migrations.AlterField(
            model_name="historicalcomplicationsglycemia",
            name="crf_status_comments",
            field=models.TextField(
                blank=True,
                default="",
                help_text="for example, why some data is still pending",
                verbose_name="Any comments related to status of this CRF",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcomplicationsglycemia",
            name="device_created",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device created"
            ),
        ),
        migrations.AlterField(
            model_name="historicalcomplicationsglycemia",
            name="device_modified",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="historicalcomplicationsglycemia",
            name="locale_created",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale created",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcomplicationsglycemia",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcomplicationsglycemia",
            name="report_datetime",
            field=models.DateTimeField(
                default=django.utils.timezone.now,
                help_text="If reporting today, use today's date/time, otherwise use the date/time this information was reported.",
                validators=[
                    edc_protocol.validators.datetime_not_before_study_start,
                    edc_model.validators.date.datetime_not_future,
                ],
                verbose_name="Report Date",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcomplicationsglycemia",
            name="revision",
            field=django_revision.revision_field.RevisionField(
                blank=True,
                default="",
                editable=False,
                help_text="System field. From git repository (tag:branch:commit), project metadata, project toml, project VERSION, or settings.",
                max_length=75,
                verbose_name="Revision",
            ),
        ),
        migrations.AlterField(
            model_name="historicalconcomitantmedication",
            name="consent_model",
            field=models.CharField(blank=True, default="", max_length=50),
        ),
        migrations.AlterField(
            model_name="historicalconcomitantmedication",
            name="consent_version",
            field=models.CharField(blank=True, default="", max_length=10),
        ),
        migrations.AlterField(
            model_name="historicalconcomitantmedication",
            name="crf_status_comments",
            field=models.TextField(
                blank=True,
                default="",
                help_text="for example, why some data is still pending",
                verbose_name="Any comments related to status of this CRF",
            ),
        ),
        migrations.AlterField(
            model_name="historicalconcomitantmedication",
            name="device_created",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device created"
            ),
        ),
        migrations.AlterField(
            model_name="historicalconcomitantmedication",
            name="device_modified",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="historicalconcomitantmedication",
            name="locale_created",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale created",
            ),
        ),
        migrations.AlterField(
            model_name="historicalconcomitantmedication",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="historicalconcomitantmedication",
            name="report_datetime",
            field=models.DateTimeField(
                default=django.utils.timezone.now,
                help_text="If reporting today, use today's date/time, otherwise use the date/time this information was reported.",
                validators=[
                    edc_protocol.validators.datetime_not_before_study_start,
                    edc_model.validators.date.datetime_not_future,
                ],
                verbose_name="Report Date",
            ),
        ),
        migrations.AlterField(
            model_name="historicalconcomitantmedication",
            name="revision",
            field=django_revision.revision_field.RevisionField(
                blank=True,
                default="",
                editable=False,
                help_text="System field. From git repository (tag:branch:commit), project metadata, project toml, project VERSION, or settings.",
                max_length=75,
                verbose_name="Revision",
            ),
        ),
    ]



# Generated by Django 5.2.6 on 2025-09-24 05:45

import django.utils.timezone
import django_revision.revision_field
import edc_model.validators.date
import edc_model_fields.fields.other_charfield
import edc_protocol.validators
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        (
            "meta_screening",
            "0067_alter_historicalscreeningpartone_report_datetime_and_more",
        ),
    ]

    operations = [
        migrations.AlterField(
            model_name="historicalscreeningpartone",
            name="acute_condition",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="",
                max_length=15,
                verbose_name="Does the patient have any acute condition requiring immediate hospital care/admission",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartone",
            name="acute_metabolic_acidosis",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="",
                help_text="lactic acidosis and/or diabetic ketoacidosis",
                max_length=15,
                verbose_name="Does the patient have any signs or symptoms of acute metabolic acidosis",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartone",
            name="alcoholism",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="",
                help_text="Evidence of alcoholism or acute alcohol intoxication: flushing, amnesia, mental confusion, nausea or vomiting, slurred speech, dehydration, dry skin and brittle hair.",
                max_length=15,
                verbose_name="Does the patient have any evidence of alcoholism or acute alcohol intoxication",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartone",
            name="congestive_heart_failure",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="",
                max_length=15,
                verbose_name="Does the patient have congestive heart failure requiring pharmacologic therapy",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartone",
            name="creatinine_units",
            field=models.CharField(
                blank=True,
                choices=[("mg/dL", "mg/dL"), ("umol/L", "μmol/L (micromoles/L)")],
                default="",
                max_length=15,
                verbose_name="Units (creatinine)",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartone",
            name="device_created",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device created"
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartone",
            name="device_modified",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartone",
            name="has_dm",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="",
                max_length=15,
                verbose_name="Is the patient known to have diabetes?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartone",
            name="liver_disease",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="",
                help_text="Evidence of chronic liver disease: Jaundice, pruritus, hepatomegaly, ascites, spider naevi and flapping tremors.",
                max_length=15,
                verbose_name="Is there clinical evidence of liver disease",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartone",
            name="locale_created",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale created",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartone",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartone",
            name="meta_phase_two",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="",
                max_length=15,
                verbose_name="Was the subject enrolled in the <u>META Phase 2</u> trial?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartone",
            name="metformin_sensitivity",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="",
                help_text="For example: Magnesium stearate, sodium carboxymethylcellulose, hypromellose",
                max_length=15,
                verbose_name="Does the patient have any known hypersensitivity to metformin or any excipients associated with its preparation",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartone",
            name="on_dm_medication",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="",
                max_length=15,
                verbose_name="Is the patient known to be taking anti-diabetic medications?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartone",
            name="p3_ltfu_comment",
            field=models.TextField(
                blank=True,
                default="",
                verbose_name="Provide any additional comments on this decision (or leave blank)",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartone",
            name="reasons_ineligible",
            field=models.TextField(
                default="", max_length=150, verbose_name="Reason not eligible"
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartone",
            name="reasons_ineligible_part_one",
            field=models.TextField(default="", editable=False, max_length=150),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartone",
            name="reasons_ineligible_part_three",
            field=models.TextField(default="", editable=False, max_length=150),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartone",
            name="reasons_ineligible_part_two",
            field=models.TextField(default="", editable=False, max_length=150),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartone",
            name="reasons_unsuitable",
            field=models.TextField(
                blank=True,
                default="",
                max_length=150,
                verbose_name="Reason not suitable for the study",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartone",
            name="renal_function_condition",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="",
                max_length=15,
                verbose_name="Does the patient have any acute condition which can alter renal function including: dehydration, severe infection or shock",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartone",
            name="report_datetime",
            field=models.DateTimeField(
                default=django.utils.timezone.now,
                help_text="Date and time of report.",
                validators=[
                    edc_protocol.validators.datetime_not_before_study_start,
                    edc_model.validators.date.datetime_not_future,
                ],
                verbose_name="Report Date and Time",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartone",
            name="revision",
            field=django_revision.revision_field.RevisionField(
                blank=True,
                default="",
                editable=False,
                help_text="System field. From git repository (tag:branch:commit), project metadata, project toml, project VERSION, or settings.",
                max_length=75,
                verbose_name="Revision",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartone",
            name="severe_htn",
            field=models.CharField(
                blank=True,
                choices=[("Yes", "Yes"), ("No", "No")],
                default="",
                help_text="Based on the above readings. Severe HTN is any BP reading > 180/110mmHg",
                max_length=15,
                verbose_name="Does the patient have severe hypertension?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartone",
            name="slug",
            field=models.CharField(
                db_index=True,
                default="",
                editable=False,
                help_text="Hold slug field values for quick search. Excludes encrypted fields",
                max_length=250,
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartone",
            name="staying_nearby_12",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="",
                max_length=15,
                verbose_name="Is the patient planning to remain in the catchment area for <u>at least 12 months</u>",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartone",
            name="staying_nearby_6",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="",
                editable=False,
                help_text="META PHASE_TWO ONLY",
                max_length=15,
                verbose_name="Is the patient planning to remain in the catchment area for at least 6 months",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartone",
            name="subject_identifier_aka",
            field=models.CharField(
                default="",
                editable=False,
                help_text="track a previously allocated identifier.",
                max_length=50,
                verbose_name="Subject Identifier a.k.a",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartone",
            name="tissue_hypoxia_condition",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="",
                help_text="Including: decompensated heart failure, respiratory failure, recent myocardial infarction or shock",
                max_length=15,
                verbose_name="Does the patient have any acute condition which can cause tissue hypoxia",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartthree",
            name="acute_condition",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="",
                max_length=15,
                verbose_name="Does the patient have any acute condition requiring immediate hospital care/admission",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartthree",
            name="acute_metabolic_acidosis",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="",
                help_text="lactic acidosis and/or diabetic ketoacidosis",
                max_length=15,
                verbose_name="Does the patient have any signs or symptoms of acute metabolic acidosis",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartthree",
            name="alcoholism",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="",
                help_text="Evidence of alcoholism or acute alcohol intoxication: flushing, amnesia, mental confusion, nausea or vomiting, slurred speech, dehydration, dry skin and brittle hair.",
                max_length=15,
                verbose_name="Does the patient have any evidence of alcoholism or acute alcohol intoxication",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartthree",
            name="congestive_heart_failure",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="",
                max_length=15,
                verbose_name="Does the patient have congestive heart failure requiring pharmacologic therapy",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartthree",
            name="creatinine_units",
            field=models.CharField(
                blank=True,
                choices=[("mg/dL", "mg/dL"), ("umol/L", "μmol/L (micromoles/L)")],
                default="",
                max_length=15,
                verbose_name="Units (creatinine)",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartthree",
            name="device_created",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device created"
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartthree",
            name="device_modified",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartthree",
            name="has_dm",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="",
                max_length=15,
                verbose_name="Is the patient known to have diabetes?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartthree",
            name="liver_disease",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="",
                help_text="Evidence of chronic liver disease: Jaundice, pruritus, hepatomegaly, ascites, spider naevi and flapping tremors.",
                max_length=15,
                verbose_name="Is there clinical evidence of liver disease",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartthree",
            name="locale_created",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale created",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartthree",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartthree",
            name="meta_phase_two",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="",
                max_length=15,
                verbose_name="Was the subject enrolled in the <u>META Phase 2</u> trial?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartthree",
            name="metformin_sensitivity",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="",
                help_text="For example: Magnesium stearate, sodium carboxymethylcellulose, hypromellose",
                max_length=15,
                verbose_name="Does the patient have any known hypersensitivity to metformin or any excipients associated with its preparation",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartthree",
            name="on_dm_medication",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="",
                max_length=15,
                verbose_name="Is the patient known to be taking anti-diabetic medications?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartthree",
            name="p3_ltfu_comment",
            field=models.TextField(
                blank=True,
                default="",
                verbose_name="Provide any additional comments on this decision (or leave blank)",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartthree",
            name="reasons_ineligible",
            field=models.TextField(
                default="", max_length=150, verbose_name="Reason not eligible"
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartthree",
            name="reasons_ineligible_part_one",
            field=models.TextField(default="", editable=False, max_length=150),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartthree",
            name="reasons_ineligible_part_three",
            field=models.TextField(default="", editable=False, max_length=150),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartthree",
            name="reasons_ineligible_part_two",
            field=models.TextField(default="", editable=False, max_length=150),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartthree",
            name="reasons_unsuitable",
            field=models.TextField(
                blank=True,
                default="",
                max_length=150,
                verbose_name="Reason not suitable for the study",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartthree",
            name="renal_function_condition",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="",
                max_length=15,
                verbose_name="Does the patient have any acute condition which can alter renal function including: dehydration, severe infection or shock",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartthree",
            name="report_datetime",
            field=models.DateTimeField(
                default=django.utils.timezone.now,
                help_text="Date and time of report.",
                validators=[
                    edc_protocol.validators.datetime_not_before_study_start,
                    edc_model.validators.date.datetime_not_future,
                ],
                verbose_name="Report Date and Time",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartthree",
            name="revision",
            field=django_revision.revision_field.RevisionField(
                blank=True,
                default="",
                editable=False,
                help_text="System field. From git repository (tag:branch:commit), project metadata, project toml, project VERSION, or settings.",
                max_length=75,
                verbose_name="Revision",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartthree",
            name="severe_htn",
            field=models.CharField(
                blank=True,
                choices=[("Yes", "Yes"), ("No", "No")],
                default="",
                help_text="Based on the above readings. Severe HTN is any BP reading > 180/110mmHg",
                max_length=15,
                verbose_name="Does the patient have severe hypertension?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartthree",
            name="slug",
            field=models.CharField(
                db_index=True,
                default="",
                editable=False,
                help_text="Hold slug field values for quick search. Excludes encrypted fields",
                max_length=250,
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartthree",
            name="staying_nearby_12",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="",
                max_length=15,
                verbose_name="Is the patient planning to remain in the catchment area for <u>at least 12 months</u>",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartthree",
            name="staying_nearby_6",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="",
                editable=False,
                help_text="META PHASE_TWO ONLY",
                max_length=15,
                verbose_name="Is the patient planning to remain in the catchment area for at least 6 months",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartthree",
            name="subject_identifier_aka",
            field=models.CharField(
                default="",
                editable=False,
                help_text="track a previously allocated identifier.",
                max_length=50,
                verbose_name="Subject Identifier a.k.a",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartthree",
            name="tissue_hypoxia_condition",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="",
                help_text="Including: decompensated heart failure, respiratory failure, recent myocardial infarction or shock",
                max_length=15,
                verbose_name="Does the patient have any acute condition which can cause tissue hypoxia",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningparttwo",
            name="acute_condition",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="",
                max_length=15,
                verbose_name="Does the patient have any acute condition requiring immediate hospital care/admission",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningparttwo",
            name="acute_metabolic_acidosis",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="",
                help_text="lactic acidosis and/or diabetic ketoacidosis",
                max_length=15,
                verbose_name="Does the patient have any signs or symptoms of acute metabolic acidosis",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningparttwo",
            name="alcoholism",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="",
                help_text="Evidence of alcoholism or acute alcohol intoxication: flushing, amnesia, mental confusion, nausea or vomiting, slurred speech, dehydration, dry skin and brittle hair.",
                max_length=15,
                verbose_name="Does the patient have any evidence of alcoholism or acute alcohol intoxication",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningparttwo",
            name="congestive_heart_failure",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="",
                max_length=15,
                verbose_name="Does the patient have congestive heart failure requiring pharmacologic therapy",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningparttwo",
            name="creatinine_units",
            field=models.CharField(
                blank=True,
                choices=[("mg/dL", "mg/dL"), ("umol/L", "μmol/L (micromoles/L)")],
                default="",
                max_length=15,
                verbose_name="Units (creatinine)",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningparttwo",
            name="device_created",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device created"
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningparttwo",
            name="device_modified",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningparttwo",
            name="has_dm",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="",
                max_length=15,
                verbose_name="Is the patient known to have diabetes?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningparttwo",
            name="liver_disease",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="",
                help_text="Evidence of chronic liver disease: Jaundice, pruritus, hepatomegaly, ascites, spider naevi and flapping tremors.",
                max_length=15,
                verbose_name="Is there clinical evidence of liver disease",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningparttwo",
            name="locale_created",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale created",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningparttwo",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningparttwo",
            name="meta_phase_two",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="",
                max_length=15,
                verbose_name="Was the subject enrolled in the <u>META Phase 2</u> trial?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningparttwo",
            name="metformin_sensitivity",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="",
                help_text="For example: Magnesium stearate, sodium carboxymethylcellulose, hypromellose",
                max_length=15,
                verbose_name="Does the patient have any known hypersensitivity to metformin or any excipients associated with its preparation",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningparttwo",
            name="on_dm_medication",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="",
                max_length=15,
                verbose_name="Is the patient known to be taking anti-diabetic medications?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningparttwo",
            name="p3_ltfu_comment",
            field=models.TextField(
                blank=True,
                default="",
                verbose_name="Provide any additional comments on this decision (or leave blank)",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningparttwo",
            name="reasons_ineligible",
            field=models.TextField(
                default="", max_length=150, verbose_name="Reason not eligible"
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningparttwo",
            name="reasons_ineligible_part_one",
            field=models.TextField(default="", editable=False, max_length=150),
        ),
        migrations.AlterField(
            model_name="historicalscreeningparttwo",
            name="reasons_ineligible_part_three",
            field=models.TextField(default="", editable=False, max_length=150),
        ),
        migrations.AlterField(
            model_name="historicalscreeningparttwo",
            name="reasons_ineligible_part_two",
            field=models.TextField(default="", editable=False, max_length=150),
        ),
        migrations.AlterField(
            model_name="historicalscreeningparttwo",
            name="reasons_unsuitable",
            field=models.TextField(
                blank=True,
                default="",
                max_length=150,
                verbose_name="Reason not suitable for the study",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningparttwo",
            name="renal_function_condition",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="",
                max_length=15,
                verbose_name="Does the patient have any acute condition which can alter renal function including: dehydration, severe infection or shock",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningparttwo",
            name="report_datetime",
            field=models.DateTimeField(
                default=django.utils.timezone.now,
                help_text="Date and time of report.",
                validators=[
                    edc_protocol.validators.datetime_not_before_study_start,
                    edc_model.validators.date.datetime_not_future,
                ],
                verbose_name="Report Date and Time",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningparttwo",
            name="revision",
            field=django_revision.revision_field.RevisionField(
                blank=True,
                default="",
                editable=False,
                help_text="System field. From git repository (tag:branch:commit), project metadata, project toml, project VERSION, or settings.",
                max_length=75,
                verbose_name="Revision",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningparttwo",
            name="severe_htn",
            field=models.CharField(
                blank=True,
                choices=[("Yes", "Yes"), ("No", "No")],
                default="",
                help_text="Based on the above readings. Severe HTN is any BP reading > 180/110mmHg",
                max_length=15,
                verbose_name="Does the patient have severe hypertension?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningparttwo",
            name="slug",
            field=models.CharField(
                db_index=True,
                default="",
                editable=False,
                help_text="Hold slug field values for quick search. Excludes encrypted fields",
                max_length=250,
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningparttwo",
            name="staying_nearby_12",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="",
                max_length=15,
                verbose_name="Is the patient planning to remain in the catchment area for <u>at least 12 months</u>",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningparttwo",
            name="staying_nearby_6",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="",
                editable=False,
                help_text="META PHASE_TWO ONLY",
                max_length=15,
                verbose_name="Is the patient planning to remain in the catchment area for at least 6 months",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningparttwo",
            name="subject_identifier_aka",
            field=models.CharField(
                default="",
                editable=False,
                help_text="track a previously allocated identifier.",
                max_length=50,
                verbose_name="Subject Identifier a.k.a",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningparttwo",
            name="tissue_hypoxia_condition",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="",
                help_text="Including: decompensated heart failure, respiratory failure, recent myocardial infarction or shock",
                max_length=15,
                verbose_name="Does the patient have any acute condition which can cause tissue hypoxia",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectrefusal",
            name="device_created",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device created"
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectrefusal",
            name="device_modified",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectrefusal",
            name="locale_created",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale created",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectrefusal",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectrefusal",
            name="other_reason",
            field=edc_model_fields.fields.other_charfield.OtherCharField(
                blank=True,
                default="",
                max_length=35,
                verbose_name="If other, please specify ...",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectrefusal",
            name="revision",
            field=django_revision.revision_field.RevisionField(
                blank=True,
                default="",
                editable=False,
                help_text="System field. From git repository (tag:branch:commit), project metadata, project toml, project VERSION, or settings.",
                max_length=75,
                verbose_name="Revision",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectrefusal",
            name="subject_identifier_aka",
            field=models.CharField(
                default="",
                editable=False,
                help_text="track a previously allocated identifier.",
                max_length=50,
                verbose_name="Subject Identifier a.k.a",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="acute_condition",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="",
                max_length=15,
                verbose_name="Does the patient have any acute condition requiring immediate hospital care/admission",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="acute_metabolic_acidosis",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="",
                help_text="lactic acidosis and/or diabetic ketoacidosis",
                max_length=15,
                verbose_name="Does the patient have any signs or symptoms of acute metabolic acidosis",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="alcoholism",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="",
                help_text="Evidence of alcoholism or acute alcohol intoxication: flushing, amnesia, mental confusion, nausea or vomiting, slurred speech, dehydration, dry skin and brittle hair.",
                max_length=15,
                verbose_name="Does the patient have any evidence of alcoholism or acute alcohol intoxication",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="congestive_heart_failure",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="",
                max_length=15,
                verbose_name="Does the patient have congestive heart failure requiring pharmacologic therapy",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="creatinine_units",
            field=models.CharField(
                blank=True,
                choices=[("mg/dL", "mg/dL"), ("umol/L", "μmol/L (micromoles/L)")],
                default="",
                max_length=15,
                verbose_name="Units (creatinine)",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="device_created",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device created"
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="device_modified",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="has_dm",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="",
                max_length=15,
                verbose_name="Is the patient known to have diabetes?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="liver_disease",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="",
                help_text="Evidence of chronic liver disease: Jaundice, pruritus, hepatomegaly, ascites, spider naevi and flapping tremors.",
                max_length=15,
                verbose_name="Is there clinical evidence of liver disease",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="locale_created",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale created",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="meta_phase_two",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="",
                max_length=15,
                verbose_name="Was the subject enrolled in the <u>META Phase 2</u> trial?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="metformin_sensitivity",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="",
                help_text="For example: Magnesium stearate, sodium carboxymethylcellulose, hypromellose",
                max_length=15,
                verbose_name="Does the patient have any known hypersensitivity to metformin or any excipients associated with its preparation",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="on_dm_medication",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="",
                max_length=15,
                verbose_name="Is the patient known to be taking anti-diabetic medications?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="p3_ltfu_comment",
            field=models.TextField(
                blank=True,
                default="",
                verbose_name="Provide any additional comments on this decision (or leave blank)",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="reasons_ineligible",
            field=models.TextField(
                default="", max_length=150, verbose_name="Reason not eligible"
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="reasons_ineligible_part_one",
            field=models.TextField(default="", editable=False, max_length=150),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="reasons_ineligible_part_three",
            field=models.TextField(default="", editable=False, max_length=150),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="reasons_ineligible_part_two",
            field=models.TextField(default="", editable=False, max_length=150),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="reasons_unsuitable",
            field=models.TextField(
                blank=True,
                default="",
                max_length=150,
                verbose_name="Reason not suitable for the study",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="renal_function_condition",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="",
                max_length=15,
                verbose_name="Does the patient have any acute condition which can alter renal function including: dehydration, severe infection or shock",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="report_datetime",
            field=models.DateTimeField(
                default=django.utils.timezone.now,
                help_text="Date and time of report.",
                validators=[
                    edc_protocol.validators.datetime_not_before_study_start,
                    edc_model.validators.date.datetime_not_future,
                ],
                verbose_name="Report Date and Time",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="revision",
            field=django_revision.revision_field.RevisionField(
                blank=True,
                default="",
                editable=False,
                help_text="System field. From git repository (tag:branch:commit), project metadata, project toml, project VERSION, or settings.",
                max_length=75,
                verbose_name="Revision",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="severe_htn",
            field=models.CharField(
                blank=True,
                choices=[("Yes", "Yes"), ("No", "No")],
                default="",
                help_text="Based on the above readings. Severe HTN is any BP reading > 180/110mmHg",
                max_length=15,
                verbose_name="Does the patient have severe hypertension?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="slug",
            field=models.CharField(
                db_index=True,
                default="",
                editable=False,
                help_text="Hold slug field values for quick search. Excludes encrypted fields",
                max_length=250,
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="staying_nearby_12",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="",
                max_length=15,
                verbose_name="Is the patient planning to remain in the catchment area for <u>at least 12 months</u>",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="staying_nearby_6",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="",
                editable=False,
                help_text="META PHASE_TWO ONLY",
                max_length=15,
                verbose_name="Is the patient planning to remain in the catchment area for at least 6 months",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="subject_identifier_aka",
            field=models.CharField(
                default="",
                editable=False,
                help_text="track a previously allocated identifier.",
                max_length=50,
                verbose_name="Subject Identifier a.k.a",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="tissue_hypoxia_condition",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="",
                help_text="Including: decompensated heart failure, respiratory failure, recent myocardial infarction or shock",
                max_length=15,
                verbose_name="Does the patient have any acute condition which can cause tissue hypoxia",
            ),
        ),
        migrations.AlterField(
            model_name="subjectrefusal",
            name="device_created",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device created"
            ),
        ),
        migrations.AlterField(
            model_name="subjectrefusal",
            name="device_modified",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="subjectrefusal",
            name="locale_created",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale created",
            ),
        ),
        migrations.AlterField(
            model_name="subjectrefusal",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="subjectrefusal",
            name="other_reason",
            field=edc_model_fields.fields.other_charfield.OtherCharField(
                blank=True,
                default="",
                max_length=35,
                verbose_name="If other, please specify ...",
            ),
        ),
        migrations.AlterField(
            model_name="subjectrefusal",
            name="revision",
            field=django_revision.revision_field.RevisionField(
                blank=True,
                default="",
                editable=False,
                help_text="System field. From git repository (tag:branch:commit), project metadata, project toml, project VERSION, or settings.",
                max_length=75,
                verbose_name="Revision",
            ),
        ),
        migrations.AlterField(
            model_name="subjectrefusal",
            name="subject_identifier_aka",
            field=models.CharField(
                default="",
                editable=False,
                help_text="track a previously allocated identifier.",
                max_length=50,
                verbose_name="Subject Identifier a.k.a",
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="acute_condition",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="",
                max_length=15,
                verbose_name="Does the patient have any acute condition requiring immediate hospital care/admission",
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="acute_metabolic_acidosis",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="",
                help_text="lactic acidosis and/or diabetic ketoacidosis",
                max_length=15,
                verbose_name="Does the patient have any signs or symptoms of acute metabolic acidosis",
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="alcoholism",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="",
                help_text="Evidence of alcoholism or acute alcohol intoxication: flushing, amnesia, mental confusion, nausea or vomiting, slurred speech, dehydration, dry skin and brittle hair.",
                max_length=15,
                verbose_name="Does the patient have any evidence of alcoholism or acute alcohol intoxication",
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="congestive_heart_failure",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="",
                max_length=15,
                verbose_name="Does the patient have congestive heart failure requiring pharmacologic therapy",
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="creatinine_units",
            field=models.CharField(
                blank=True,
                choices=[("mg/dL", "mg/dL"), ("umol/L", "μmol/L (micromoles/L)")],
                default="",
                max_length=15,
                verbose_name="Units (creatinine)",
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="device_created",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device created"
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="device_modified",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="has_dm",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="",
                max_length=15,
                verbose_name="Is the patient known to have diabetes?",
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="liver_disease",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="",
                help_text="Evidence of chronic liver disease: Jaundice, pruritus, hepatomegaly, ascites, spider naevi and flapping tremors.",
                max_length=15,
                verbose_name="Is there clinical evidence of liver disease",
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="locale_created",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale created",
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="meta_phase_two",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="",
                max_length=15,
                verbose_name="Was the subject enrolled in the <u>META Phase 2</u> trial?",
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="metformin_sensitivity",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="",
                help_text="For example: Magnesium stearate, sodium carboxymethylcellulose, hypromellose",
                max_length=15,
                verbose_name="Does the patient have any known hypersensitivity to metformin or any excipients associated with its preparation",
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="on_dm_medication",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="",
                max_length=15,
                verbose_name="Is the patient known to be taking anti-diabetic medications?",
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="p3_ltfu_comment",
            field=models.TextField(
                blank=True,
                default="",
                verbose_name="Provide any additional comments on this decision (or leave blank)",
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="reasons_ineligible",
            field=models.TextField(
                default="", max_length=150, verbose_name="Reason not eligible"
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="reasons_ineligible_part_one",
            field=models.TextField(default="", editable=False, max_length=150),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="reasons_ineligible_part_three",
            field=models.TextField(default="", editable=False, max_length=150),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="reasons_ineligible_part_two",
            field=models.TextField(default="", editable=False, max_length=150),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="reasons_unsuitable",
            field=models.TextField(
                blank=True,
                default="",
                max_length=150,
                verbose_name="Reason not suitable for the study",
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="renal_function_condition",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="",
                max_length=15,
                verbose_name="Does the patient have any acute condition which can alter renal function including: dehydration, severe infection or shock",
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="report_datetime",
            field=models.DateTimeField(
                default=django.utils.timezone.now,
                help_text="Date and time of report.",
                validators=[
                    edc_protocol.validators.datetime_not_before_study_start,
                    edc_model.validators.date.datetime_not_future,
                ],
                verbose_name="Report Date and Time",
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="revision",
            field=django_revision.revision_field.RevisionField(
                blank=True,
                default="",
                editable=False,
                help_text="System field. From git repository (tag:branch:commit), project metadata, project toml, project VERSION, or settings.",
                max_length=75,
                verbose_name="Revision",
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="severe_htn",
            field=models.CharField(
                blank=True,
                choices=[("Yes", "Yes"), ("No", "No")],
                default="",
                help_text="Based on the above readings. Severe HTN is any BP reading > 180/110mmHg",
                max_length=15,
                verbose_name="Does the patient have severe hypertension?",
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="slug",
            field=models.CharField(
                db_index=True,
                default="",
                editable=False,
                help_text="Hold slug field values for quick search. Excludes encrypted fields",
                max_length=250,
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="staying_nearby_12",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="",
                max_length=15,
                verbose_name="Is the patient planning to remain in the catchment area for <u>at least 12 months</u>",
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="staying_nearby_6",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="",
                editable=False,
                help_text="META PHASE_TWO ONLY",
                max_length=15,
                verbose_name="Is the patient planning to remain in the catchment area for at least 6 months",
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="subject_identifier_aka",
            field=models.CharField(
                default="",
                editable=False,
                help_text="track a previously allocated identifier.",
                max_length=50,
                verbose_name="Subject Identifier a.k.a",
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="tissue_hypoxia_condition",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="",
                help_text="Including: decompensated heart failure, respiratory failure, recent myocardial infarction or shock",
                max_length=15,
                verbose_name="Does the patient have any acute condition which can cause tissue hypoxia",
            ),
        ),
    ]



from .eligibility import (
    MetaEligibility,
    SubjectScreeningEligibilityError,
    get_display_label,
)
from .eligibility_part_one import EligibilityPartOne
from .eligibility_part_three import EligibilityPartThreePhaseThree
from .eligibility_part_two import EligibilityPartTwo

__all__ = [
    "EligibilityPartOne",
    "EligibilityPartThreePhaseThree",
    "EligibilityPartTwo",
    "MetaEligibility",
    "SubjectScreeningEligibilityError",
    "get_display_label",
]



from .blood_results_fbc_form import BloodResultsFbcForm
from .blood_results_hba1c_form import BloodResultsHba1cForm
from .blood_results_ins_form import BloodResultsInsForm
from .blood_results_lft_form import BloodResultsLftForm
from .blood_results_lipids_form import BloodResultsLipidsForm
from .blood_results_rft_form import BloodResultsRftForm

__all__ = [
    "BloodResultsFbcForm",
    "BloodResultsHba1cForm",
    "BloodResultsInsForm",
    "BloodResultsLftForm",
    "BloodResultsLipidsForm",
    "BloodResultsRftForm",
]



import urllib.parse
from datetime import date, datetime

from dateutil.relativedelta import relativedelta
from django.core.exceptions import ObjectDoesNotExist
from edc_appointment.constants import NEW_APPT
from edc_appointment.models import Appointment
from edc_registration.models import RegisteredSubject
from edc_utils import formatted_date, get_utcnow
from edc_visit_tracking.constants import MISSED_VISIT
from tqdm import tqdm

from meta_prn.models import EndOfStudy, OffSchedule, OffStudyMedication
from meta_subject.models import SubjectVisit, SubjectVisitMissed

urllib.parse.quote("D-cHO$?N-1cOYHl^2^GDbZ:o-^X")

visit_codes = [
    "1000",
    "1005",
    "1010",
    "1030",
    "1060",
    "1090",
    "1120",
    "1150",
    "1180",
    "1210",
    "1240",
    "1270",
    "1300",
    "1330",
    "1360",
]


def is_sublist(a, b):
    if not a:
        return True
    if not b:
        return False
    return b[: len(a)] == a or is_sublist(a, b[1:])


def get_missed_visit_codes(subject_identifier: str) -> list[str]:
    """Return visit codes from SubjectVisitMissed
    reports for this subject.
    """
    return [
        missed_obj.subject_visit.visit_code
        for missed_obj in SubjectVisitMissed.objects.filter(
            subject_visit__subject_identifier=subject_identifier
        ).order_by("report_datetime")
    ]


def get_missed_visit_codes_from_subject_visit(subject_identifier: str) -> list[str]:
    return [
        missed_obj.visit_code
        for missed_obj in SubjectVisit.objects.filter(
            subject_identifier=subject_identifier, reason=MISSED_VISIT
        ).order_by("report_datetime")
    ]


def run():
    result = {}
    total = RegisteredSubject.objects.all().count()
    for obj in tqdm(
        RegisteredSubject.objects.all().order_by("subject_identifier"), total=total
    ):
        missed_visit_codes = get_missed_visit_codes(obj.subject_identifier)
        if len(missed_visit_codes) > 2 and is_sublist(missed_visit_codes, visit_codes):
            result.update({obj.subject_identifier: missed_visit_codes})
    return result


def run2():
    result = {}
    total = RegisteredSubject.objects.all().count()
    for obj in tqdm(
        RegisteredSubject.objects.all().order_by("subject_identifier"), total=total
    ):
        missed_visit_codes = get_missed_visit_codes_from_subject_visit(obj.subject_identifier)
        if len(missed_visit_codes) > 2 and is_sublist(missed_visit_codes, visit_codes):
            result.update({obj.subject_identifier: missed_visit_codes})
    return result


def new_appointments():
    result = {}
    total = RegisteredSubject.objects.all().count()
    for obj in tqdm(
        RegisteredSubject.objects.all().order_by("subject_identifier"), total=total
    ):
        codes = []
        for appointment in Appointment.objects.filter(
            subject_identifier=obj.subject_identifier,
            appt_status=NEW_APPT,
            timepoint_datetime__lte=get_utcnow(),
        ).order_by("timepoint_datetime"):
            codes.append(appointment.visit_code)
            if len(codes) >= 2 and is_sublist(codes, visit_codes):
                result.update({obj.subject_identifier: codes})
    return result


def new_appointments_within(months: int):
    result = {}
    total = RegisteredSubject.objects.all().count()
    for obj in tqdm(
        RegisteredSubject.objects.all().order_by("subject_identifier"), total=total
    ):
        codes = []
        appointment = (
            Appointment.objects.filter(
                subject_identifier=obj.subject_identifier,
                appt_status=NEW_APPT,
                timepoint_datetime__lte=get_utcnow() - relativedelta(months=months),
            )
            .order_by("timepoint_datetime")
            .last()
        )
        if appointment:
            codes.append(appointment.visit_code)
            result.update({obj.subject_identifier: codes})
    return result


class Result:
    """Used with run3."""

    def __init__(  # noqa: PLR0913
        self,
        subject_identifier: str,
        sid: str,
        first_visit: datetime,
        first_missed_visit: datetime,
        last_missed_visit: datetime,
        last_visit: datetime,
        off_meds: date,
        offschedule: date,
        offstudy: date,
        codes: list[str],
    ):
        self.subject_identifier = subject_identifier
        self.sid = sid
        if last_missed_visit and first_missed_visit:
            self.missed = (last_missed_visit - first_missed_visit).days
        else:
            self.missed = 0
        self.onstudy = (last_visit - first_visit).days
        self.attended = self.onstudy - self.missed
        if last_missed_visit:
            self.attended_after_missed = last_visit > last_missed_visit
        else:
            self.attended_after_missed = False
        self.offmeds = (off_meds - first_visit.date()).days if off_meds else 0
        self.offschedule = (offschedule - first_visit.date()).days if offschedule else 0
        self.offstudy = (offstudy - first_visit.date()).days if offstudy else 0
        self.last_visit_date = last_visit.date()
        self.offstudy_date = offstudy
        self.visit_codes = codes

    def __str__(self):
        return f"{self.subject_identifier} {self.visit_codes}"

    def formatted(self) -> str:
        """Copy/paste output into text file"""
        return (
            f"{self.subject_identifier},{self.sid},{self.onstudy},{self.missed},"
            f"{self.attended_after_missed},{self.offmeds},{self.offschedule},"
            f"{self.offstudy},{formatted_date(self.offstudy_date)},"
            f"{';'.join(self.visit_codes)}"
        )


def runner(result=None):
    """
    result = runner(new_appointments())
    for r in result.values():
        print(r.formatted())
    """
    new_result = {}
    for subject_identifier, vcodes in result.items():
        sid = RegisteredSubject.objects.get(subject_identifier=subject_identifier).sid
        first_visit = (
            SubjectVisit.objects.filter(subject_identifier=subject_identifier)
            .order_by("report_datetime")
            .first()
        ).report_datetime
        try:
            first_missed_visit = SubjectVisit.objects.get(
                subject_identifier=subject_identifier,
                visit_code=vcodes[0],
                reason=MISSED_VISIT,
            ).report_datetime
        except ObjectDoesNotExist:
            first_missed_visit = 0
        try:
            last_missed_visit = SubjectVisit.objects.get(
                subject_identifier=subject_identifier,
                visit_code=vcodes[-1],
                reason=MISSED_VISIT,
            ).report_datetime
        except ObjectDoesNotExist:
            last_missed_visit = 0
        last_visit = (
            SubjectVisit.objects.filter(subject_identifier=subject_identifier)
            .order_by("report_datetime")
            .last()
        ).report_datetime
        try:
            off_meds = OffStudyMedication.objects.get(
                subject_identifier=subject_identifier
            ).last_dose_date
        except ObjectDoesNotExist:
            off_meds = None
        try:
            offschedule = OffSchedule.objects.get(
                subject_identifier=subject_identifier
            ).offschedule_datetime
        except ObjectDoesNotExist:
            offschedule = None
        else:
            offschedule = offschedule.date()

        try:
            offstudy = EndOfStudy.objects.get(
                subject_identifier=subject_identifier
            ).last_seen_date
        except ObjectDoesNotExist:
            offstudy = None

        new_result.update(
            {
                subject_identifier: Result(
                    subject_identifier,
                    sid,
                    first_visit,
                    first_missed_visit,
                    last_missed_visit,
                    last_visit,
                    off_meds,
                    offschedule,
                    offstudy,
                    vcodes,
                )
            }
        )
    return new_result



from .health_economics_simple_form import HealthEconomicsSimpleForm
from .health_economics_update_form import HealthEconomicsUpdateForm

__all__ = ["HealthEconomicsSimpleForm", "HealthEconomicsUpdateForm"]



from django.db import models
from edc_identifier.model_mixins import NonUniqueSubjectIdentifierModelMixin
from edc_model.models import BaseUuidModel
from edc_model.models.historical_records import HistoricalRecords
from edc_model_fields.fields.other_charfield import OtherCharField
from edc_search.model_mixins import SearchSlugManager
from edc_sites.managers import CurrentSiteManager
from edc_sites.model_mixins import SiteModelMixin
from edc_utils import get_utcnow

from ..choices import REFUSAL_REASONS
from .subject_screening import SubjectScreening


class SubjectRefusalManager(SearchSlugManager, models.Manager):
    def get_by_natural_key(self, subject_identifier):
        return self.get(subject_identifier=subject_identifier)


class SubjectRefusal(NonUniqueSubjectIdentifierModelMixin, SiteModelMixin, BaseUuidModel):
    subject_screening = models.ForeignKey(SubjectScreening, on_delete=models.PROTECT)

    subject_identifier = models.CharField(max_length=50, editable=False)

    screening_identifier = models.CharField(max_length=50, editable=False)

    report_datetime = models.DateTimeField(
        verbose_name="Report Date and Time", default=get_utcnow
    )

    reason = models.CharField(
        verbose_name="Reason for refusal to join",
        max_length=25,
        choices=REFUSAL_REASONS,
    )

    other_reason = OtherCharField()

    objects = SubjectRefusalManager()

    on_site = CurrentSiteManager()

    history = HistoricalRecords()

    def save(self, *args, **kwargs):
        self.screening_identifier = self.subject_screening.screening_identifier
        self.subject_identifier = self.subject_screening.subject_identifier
        self.subject_identifier_as_pk = self.subject_screening.subject_identifier_as_pk
        super().save(*args, **kwargs)

    def __str__(self):
        return (
            f"{self.screening_identifier} {self.subject_screening.gender} "
            f"{self.subject_screening.age_in_years}"
        )

    def natural_key(self):
        return (self.subject_identifier,)

    def get_search_slug_fields(self):
        return "screening_identifier", "subject_identifier"

    class Meta:
        verbose_name = "Subject Refusal"
        verbose_name_plural = "Subject Refusals"



# Generated by Django 3.2.11 on 2022-07-19 22:08

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("meta_subject", "0128_auto_20220720_0055"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="bloodresultsrft",
            name="egfr_percent_change",
        ),
        migrations.RemoveField(
            model_name="historicalbloodresultsrft",
            name="egfr_percent_change",
        ),
    ]



from django import forms
from edc_crf.modelform_mixins import CrfModelFormMixin

from ..form_validators import GlucoseFbgFormValidator
from ..models import GlucoseFbg


class GlucoseFbgForm(CrfModelFormMixin, forms.ModelForm):
    form_validator_cls = GlucoseFbgFormValidator

    class Meta:
        model = GlucoseFbg
        fields = "__all__"



# Generated by Django 5.2.3 on 2025-07-03 22:44

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("meta_prn", "0064_auto_20250602_2143"),
    ]

    operations = [
        migrations.AlterField(
            model_name="historicaloffstudymedication",
            name="subject_identifier",
            field=models.CharField(db_index=True, max_length=50),
        ),
        migrations.AlterField(
            model_name="offstudymedication",
            name="subject_identifier",
            field=models.CharField(max_length=50, unique=True),
        ),
    ]



# Generated by Django 5.1 on 2024-09-11 00:30

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("meta_pharmacy", "0003_auto_20240909_2335"),
    ]

    operations = [
        migrations.AlterField(
            model_name="historicalsubstitutions",
            name="report_datetime",
            field=models.DateTimeField(null=True),
        ),
        migrations.AlterField(
            model_name="substitutions",
            name="report_datetime",
            field=models.DateTimeField(null=True),
        ),
    ]



# Generated by Django 4.0.5 on 2022-06-28 11:35

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("meta_screening", "0049_historicalscreeningpartone_p3_ltfu_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="historicalscreeningpartone",
            name="agree_to_p3",
            field=models.CharField(
                choices=[
                    ("Yes", "Yes"),
                    ("No", "No"),
                    (
                        "N/A",
                        "Not applicable, subject is not eligible based on the criteria above",
                    ),
                ],
                default="Yes",
                max_length=15,
                verbose_name="Has the patient agreed to complete/return for the second stage of the screening?",
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningpartthree",
            name="agree_to_p3",
            field=models.CharField(
                choices=[
                    ("Yes", "Yes"),
                    ("No", "No"),
                    (
                        "N/A",
                        "Not applicable, subject is not eligible based on the criteria above",
                    ),
                ],
                default="Yes",
                max_length=15,
                verbose_name="Has the patient agreed to complete/return for the second stage of the screening?",
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningparttwo",
            name="agree_to_p3",
            field=models.CharField(
                choices=[
                    ("Yes", "Yes"),
                    ("No", "No"),
                    (
                        "N/A",
                        "Not applicable, subject is not eligible based on the criteria above",
                    ),
                ],
                default="Yes",
                max_length=15,
                verbose_name="Has the patient agreed to complete/return for the second stage of the screening?",
            ),
        ),
        migrations.AddField(
            model_name="historicalsubjectscreening",
            name="agree_to_p3",
            field=models.CharField(
                choices=[
                    ("Yes", "Yes"),
                    ("No", "No"),
                    (
                        "N/A",
                        "Not applicable, subject is not eligible based on the criteria above",
                    ),
                ],
                default="Yes",
                max_length=15,
                verbose_name="Has the patient agreed to complete/return for the second stage of the screening?",
            ),
        ),
        migrations.AddField(
            model_name="subjectscreening",
            name="agree_to_p3",
            field=models.CharField(
                choices=[
                    ("Yes", "Yes"),
                    ("No", "No"),
                    (
                        "N/A",
                        "Not applicable, subject is not eligible based on the criteria above",
                    ),
                ],
                default="Yes",
                max_length=15,
                verbose_name="Has the patient agreed to complete/return for the second stage of the screening?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartone",
            name="advised_to_fast",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=15,
                verbose_name="Has the patient been advised to return FASTED for the second stage of the screening?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartone",
            name="p3_ltfu",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Undecided / Not applicable")],
                default="N/A",
                help_text="Only applicable if the subject missed the appointment for the second stage of screening. See above",
                max_length=15,
                verbose_name="Should additional attempts be made to contact this subject",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartone",
            name="p3_ltfu_comment",
            field=models.TextField(
                blank=True,
                null=True,
                verbose_name="Provide any additional comments on this decision (or leave blank)",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartone",
            name="p3_ltfu_date",
            field=models.DateField(
                blank=True,
                help_text="Must be after the appointment date for the second stage of screening (P3)",
                null=True,
                verbose_name="Date decision made",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartthree",
            name="advised_to_fast",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=15,
                verbose_name="Has the patient been advised to return FASTED for the second stage of the screening?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartthree",
            name="p3_ltfu",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Undecided / Not applicable")],
                default="N/A",
                help_text="Only applicable if the subject missed the appointment for the second stage of screening. See above",
                max_length=15,
                verbose_name="Should additional attempts be made to contact this subject",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartthree",
            name="p3_ltfu_comment",
            field=models.TextField(
                blank=True,
                null=True,
                verbose_name="Provide any additional comments on this decision (or leave blank)",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartthree",
            name="p3_ltfu_date",
            field=models.DateField(
                blank=True,
                help_text="Must be after the appointment date for the second stage of screening (P3)",
                null=True,
                verbose_name="Date decision made",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningparttwo",
            name="advised_to_fast",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=15,
                verbose_name="Has the patient been advised to return FASTED for the second stage of the screening?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningparttwo",
            name="p3_ltfu",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Undecided / Not applicable")],
                default="N/A",
                help_text="Only applicable if the subject missed the appointment for the second stage of screening. See above",
                max_length=15,
                verbose_name="Should additional attempts be made to contact this subject",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningparttwo",
            name="p3_ltfu_comment",
            field=models.TextField(
                blank=True,
                null=True,
                verbose_name="Provide any additional comments on this decision (or leave blank)",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningparttwo",
            name="p3_ltfu_date",
            field=models.DateField(
                blank=True,
                help_text="Must be after the appointment date for the second stage of screening (P3)",
                null=True,
                verbose_name="Date decision made",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="advised_to_fast",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=15,
                verbose_name="Has the patient been advised to return FASTED for the second stage of the screening?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="p3_ltfu",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Undecided / Not applicable")],
                default="N/A",
                help_text="Only applicable if the subject missed the appointment for the second stage of screening. See above",
                max_length=15,
                verbose_name="Should additional attempts be made to contact this subject",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="p3_ltfu_comment",
            field=models.TextField(
                blank=True,
                null=True,
                verbose_name="Provide any additional comments on this decision (or leave blank)",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="p3_ltfu_date",
            field=models.DateField(
                blank=True,
                help_text="Must be after the appointment date for the second stage of screening (P3)",
                null=True,
                verbose_name="Date decision made",
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="advised_to_fast",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=15,
                verbose_name="Has the patient been advised to return FASTED for the second stage of the screening?",
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="p3_ltfu",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Undecided / Not applicable")],
                default="N/A",
                help_text="Only applicable if the subject missed the appointment for the second stage of screening. See above",
                max_length=15,
                verbose_name="Should additional attempts be made to contact this subject",
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="p3_ltfu_comment",
            field=models.TextField(
                blank=True,
                null=True,
                verbose_name="Provide any additional comments on this decision (or leave blank)",
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="p3_ltfu_date",
            field=models.DateField(
                blank=True,
                help_text="Must be after the appointment date for the second stage of screening (P3)",
                null=True,
                verbose_name="Date decision made",
            ),
        ),
    ]



from django import forms
from django.utils.safestring import mark_safe
from edc_action_item.forms import ActionItemCrfFormMixin
from edc_crf.crf_form_validator import CrfFormValidator
from edc_crf.modelform_mixins import CrfModelFormMixin
from edc_egfr.form_validator_mixins import EgfrCkdEpiFormValidatorMixin
from edc_lab_panel.panels import rft_panel
from edc_lab_results.form_validator_mixins import BloodResultsFormValidatorMixin
from edc_registration.models import RegisteredSubject
from edc_utils import age
from edc_visit_schedule.utils import is_baseline
from edc_vitals.form_validators import BmiFormValidatorMixin

from ...models import BloodResultsRft, FollowupVitals, PhysicalExam


class BloodResultsRftFormValidator(
    BloodResultsFormValidatorMixin,
    EgfrCkdEpiFormValidatorMixin,
    BmiFormValidatorMixin,
    CrfFormValidator,
):
    panel = rft_panel

    def clean(self):
        super().clean()
        self.validate_bmi()
        if self.cleaned_data.get("creatinine_value") and self.cleaned_data.get(
            "creatinine_units"
        ):
            rs = RegisteredSubject.objects.get(
                subject_identifier=self.related_visit.subject_identifier
            )
            age_in_years = age(rs.dob, self.report_datetime).years

            self.validate_egfr(
                gender=rs.gender, age_in_years=age_in_years, ethnicity=rs.ethnicity
            )

    def get_weight_in_kgs(self) -> float | None:
        if is_baseline(self.related_visit):
            obj = (
                PhysicalExam.objects.filter(
                    subject_visit=self.related_visit, weight__isnull=False
                )
                .order_by("report_datetime")
                .last()
            )
        else:
            obj = (
                FollowupVitals.objects.filter(
                    subject_visit=self.related_visit, weight__isnull=False
                )
                .order_by("report_datetime")
                .last()
            )
        if obj:
            return obj.weight
        return None


class BloodResultsRftForm(ActionItemCrfFormMixin, CrfModelFormMixin, forms.ModelForm):
    form_validator_cls = BloodResultsRftFormValidator

    class Meta(ActionItemCrfFormMixin.Meta):
        model = BloodResultsRft
        fields = "__all__"
        help_texts = {  # noqa: RUF012
            "action_identifier": "(read-only)",
            "egfr_value": mark_safe(  # nosec B308
                "Calculated using 2009 CKD-EPI Creatinine. "
                "See https://nephron.com/epi_equation"
            ),
            "egfr_drop_value": mark_safe(  # nosec B308
                "Calculated using 2009 CKD-EPI Creatinine. "
                "See https://nephron.com/epi_equation"
            ),
        }



from clinicedc_constants import (
    CLOSED,
    DEAD,
    GRADE3,
    GRADE4,
    GRADE5,
    HIGH_PRIORITY,
    LTFU,
    NO,
    YES,
)
from django.apps import apps as django_apps
from django.core.exceptions import MultipleObjectsReturned, ObjectDoesNotExist
from django.utils.html import format_html
from django.utils.safestring import mark_safe
from django.utils.translation import gettext as _
from edc_action_item.action_with_notification import ActionWithNotification
from edc_action_item.site_action_items import site_action_items
from edc_adverse_event.constants import (
    AE_FOLLOWUP_ACTION,
    AE_INITIAL_ACTION,
    AE_SUSAR_ACTION,
    AE_TMG_ACTION,
    DEATH_REPORT_ACTION,
    DEATH_REPORT_TMG_ACTION,
)
from edc_lab_results.constants import (
    BLOOD_RESULTS_FBC_ACTION,
    BLOOD_RESULTS_GLU_ACTION,
    BLOOD_RESULTS_LFT_ACTION,
    BLOOD_RESULTS_LIPIDS_ACTION,
    BLOOD_RESULTS_RFT_ACTION,
)
from edc_notification.utils import get_email_contacts
from edc_visit_schedule.utils import get_offschedule_models

from meta_prn.constants import OFFSTUDY_MEDICATION_ACTION
from meta_prn.pregnancy_action_item_mixin import PregnancyActionItemMixin
from meta_subject.constants import FOLLOWUP_EXAMINATION_ACTION


class AeFollowupAction(ActionWithNotification):
    name = AE_FOLLOWUP_ACTION
    display_name = "Submit AE Followup Report"
    notification_display_name = "AE Followup Report"
    parent_action_names = (AE_INITIAL_ACTION, AE_FOLLOWUP_ACTION)
    reference_model = "meta_ae.aefollowup"
    related_reference_model = "meta_ae.aeinitial"
    related_reference_fk_attr = "ae_initial"
    create_by_user = False
    show_link_to_changelist = True
    admin_site_name = "meta_ae_admin"
    instructions = format_html(
        _(
            "Upon submission the TMG group will be notified "
            'by email at <a href="mailto:{email1}">{email2}</a>'
        ),
        email1=get_email_contacts("tmg") or "#",
        email2=get_email_contacts("tmg") or "unknown",
    )
    priority = HIGH_PRIORITY

    def get_next_actions(self):
        next_actions = ()

        # add AE followup to next_actions if followup.
        next_actions = self.append_to_next_if_required(
            next_actions=next_actions,
            action_name=self.name,
            required=self.reference_obj.followup == YES,
        )

        # add Death Report to next_actions if G5/Death
        next_actions = self.append_to_next_if_required(
            next_actions=next_actions,
            action_name=DEATH_REPORT_ACTION,
            required=(
                self.reference_obj.outcome == DEAD or self.reference_obj.ae_grade == GRADE5
            ),
        )

        # add Study termination to next_actions if LTFU
        if self.reference_obj.outcome == LTFU:
            for offschedule_model in get_offschedule_models(
                subject_identifier=self.subject_identifier,
                report_datetime=self.reference_obj.report_datetime,
            ):
                action_cls = site_action_items.get_by_model(model=offschedule_model)
                next_actions = self.append_to_next_if_required(
                    next_actions=next_actions,
                    action_name=action_cls.name,
                    required=True,
                )
        return next_actions


class AeInitialAction(ActionWithNotification):
    name = AE_INITIAL_ACTION
    display_name = "Submit AE Initial Report"
    notification_display_name = "AE Initial Report"
    parent_action_names = (
        BLOOD_RESULTS_LIPIDS_ACTION,
        BLOOD_RESULTS_GLU_ACTION,
        BLOOD_RESULTS_LFT_ACTION,
        BLOOD_RESULTS_RFT_ACTION,
        BLOOD_RESULTS_FBC_ACTION,
        FOLLOWUP_EXAMINATION_ACTION,
    )
    reference_model = "meta_ae.aeinitial"
    show_link_to_changelist = True
    show_link_to_add = True
    admin_site_name = "meta_ae_admin"
    instructions = "Complete the initial AE report"
    priority = HIGH_PRIORITY

    def get_next_actions(self):
        """Returns next actions.

        1. Add death report action if death
        """
        next_actions = ()
        deceased = (
            self.reference_obj.ae_grade == GRADE5 or self.reference_obj.sae_reason.name == DEAD
        )

        # add next AeFollowup if not deceased
        if not deceased:
            next_actions = self.append_to_next_if_required(
                action_name=AE_FOLLOWUP_ACTION, next_actions=next_actions
            )

        # add next AE_SUSAR_ACTION if SUSAR == YES
        next_actions = self.append_to_next_if_required(
            next_actions=next_actions,
            action_name=AE_SUSAR_ACTION,
            required=(
                self.reference_obj.susar == YES and self.reference_obj.susar_reported == NO
            ),
        )

        # add next Death report if G5/Death
        next_actions = self.append_to_next_if_required(
            next_actions=next_actions,
            action_name=DEATH_REPORT_ACTION,
            required=deceased,
        )

        # add next AE Tmg if G5/Death
        next_actions = self.append_to_next_if_required(
            next_actions=next_actions, action_name=AE_TMG_ACTION, required=deceased
        )
        # add next AeTmgAction if G4
        next_actions = self.append_to_next_if_required(
            next_actions=next_actions,
            action_name=AE_TMG_ACTION,
            required=self.reference_obj.ae_grade == GRADE4,
        )
        # add next AeTmgAction if G3 and is an SAE
        return self.append_to_next_if_required(
            next_actions=next_actions,
            action_name=AE_TMG_ACTION,
            required=(self.reference_obj.ae_grade == GRADE3 and self.reference_obj.sae == YES),
        )


class AeSusarAction(ActionWithNotification):
    name = AE_SUSAR_ACTION
    display_name = "Submit AE SUSAR Report"
    notification_display_name = "AE SUSAR Report"
    parent_action_names = (AE_INITIAL_ACTION,)
    reference_model = "meta_ae.aesusar"
    related_reference_model = "meta_ae.aeinitial"
    related_reference_fk_attr = "ae_initial"
    create_by_user = False
    show_link_to_changelist = True
    admin_site_name = "meta_ae_admin"
    instructions = "Complete the AE SUSAR report"
    priority = HIGH_PRIORITY


class AeTmgAction(ActionWithNotification):
    name = AE_TMG_ACTION
    display_name = "TMG AE Report pending"
    notification_display_name = "TMG AE Report"
    parent_action_names = (AE_INITIAL_ACTION, AE_FOLLOWUP_ACTION, AE_TMG_ACTION)
    reference_model = "meta_ae.aetmg"
    related_reference_model = "meta_ae.aeinitial"
    related_reference_fk_attr = "ae_initial"
    create_by_user = False
    color_style = "info"
    show_link_to_changelist = True
    admin_site_name = "meta_ae_admin"
    instructions = mark_safe("This report is to be completed by the TMG only.")  # nosec B308
    priority = HIGH_PRIORITY

    def close_action_item_on_save(self):
        return self.reference_obj.report_status == CLOSED


class DeathReportAction(PregnancyActionItemMixin, ActionWithNotification):
    name = DEATH_REPORT_ACTION
    display_name = "Submit Death Report"
    notification_display_name = "Death Report"
    reference_model = "meta_ae.deathreport"
    parent_action_names = (AE_INITIAL_ACTION, AE_FOLLOWUP_ACTION)
    show_link_to_changelist = True
    show_link_to_add = True
    admin_site_name = "meta_ae_admin"
    priority = HIGH_PRIORITY
    singleton = True
    dirty_fields = ("cause_of_death",)

    def get_next_actions(self):
        """Adds 1 DEATHReportTMG if not yet created and
        END_OF_STUDY_ACTION if required.
        """
        # DEATH_REPORT_TMG_ACTION
        try:
            self.action_item_model_cls().objects.get(
                parent_action_item=self.reference_obj.action_item,
                related_action_item=self.reference_obj.action_item,
                action_type__name=DEATH_REPORT_TMG_ACTION,
            )
        except ObjectDoesNotExist:
            next_actions = [DEATH_REPORT_TMG_ACTION]
        else:
            next_actions = []

        off_schedule_cls = django_apps.get_model("meta_prn.endofstudy")
        try:
            off_schedule_cls.objects.get(subject_identifier=self.subject_identifier)
        except ObjectDoesNotExist:
            next_actions.extend(
                [self.get_next_offschedule_action(), OFFSTUDY_MEDICATION_ACTION]
            )
        return next_actions


class DeathReportTmgAction(ActionWithNotification):
    name = DEATH_REPORT_TMG_ACTION
    display_name = "TMG Death Report pending"
    notification_display_name = "TMG Death Report"
    parent_action_names = (DEATH_REPORT_ACTION, DEATH_REPORT_TMG_ACTION)
    reference_model = "meta_ae.deathreporttmg"
    related_reference_model = "meta_ae.deathreport"
    related_reference_fk_attr = "death_report"
    priority = HIGH_PRIORITY
    create_by_user = False
    color_style = "info"
    show_link_to_changelist = True
    admin_site_name = "meta_ae_admin"
    instructions = mark_safe("This report is to be completed by the TMG only.")  # nosec B308

    def reopen_action_item_on_change(self):
        """Do not reopen if status is CLOSED."""
        return self.reference_obj.report_status != CLOSED

    @property
    def matching_cause_of_death(self):
        """Returns True if cause_of_death on TMG Death Report matches
        cause_of_death on Death Report.
        """
        return (
            self.reference_obj.death_report.cause_of_death == self.reference_obj.cause_of_death
        )

    def close_action_item_on_save(self):
        if self.matching_cause_of_death:
            self.delete_children_if_new(parent_action_item=self.action_item)
        return self.reference_obj.report_status == CLOSED

    def get_next_actions(self):
        """Returns a second DeathReportTmgAction if the
        submitted report does not match the cause of death
        of the original death report.

        Also, no more than two DeathReportTmgAction can exist.
        """
        next_actions = []
        try:
            self.action_item_model_cls().objects.get(
                parent_action_item=self.related_action_item,
                related_action_item=self.related_action_item,
                action_type__name=self.name,
            )
        except ObjectDoesNotExist:
            pass
        except MultipleObjectsReturned:
            # because more than one action item has the same
            # parent_action_item and related_action_item. this
            # only occurs for older data.
            pass
        else:
            if (
                self.action_item_model_cls()
                .objects.filter(
                    related_action_item=self.related_action_item,
                    action_type__name=self.name,
                )
                .count()
                < 2
            ) and (
                self.reference_obj.cause_of_death
                != self.related_action_item.reference_obj.cause_of_death
            ):
                next_actions = ["self"]
        return next_actions


site_action_items.register(DeathReportAction)
site_action_items.register(DeathReportTmgAction)
site_action_items.register(AeFollowupAction)
site_action_items.register(AeInitialAction)
site_action_items.register(AeSusarAction)
site_action_items.register(AeTmgAction)



# Generated by Django 5.2.7 on 2025-10-24 04:17

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("meta_consent", "0034_remove_subjectconsentspfq_site_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="historicalsubjectconsent",
            name="consent_definition_name",
            field=models.CharField(
                default="",
                editable=False,
                max_length=50,
                verbose_name="Consent definition",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectconsentv1",
            name="consent_definition_name",
            field=models.CharField(
                default="",
                editable=False,
                max_length=50,
                verbose_name="Consent definition",
            ),
        ),
        migrations.AlterField(
            model_name="subjectconsent",
            name="consent_definition_name",
            field=models.CharField(
                default="",
                editable=False,
                max_length=50,
                verbose_name="Consent definition",
            ),
        ),
    ]
